/***********************************************************************
 * CONFIGURACIÓ
 ***********************************************************************/

/**
 * Flag debug
 * Important pel fet que es passa al WS del bootloader, i aquest ens donarà versió "beta" o no depenent d'aquest flag.
 * Si som DEV's, posem TRUE, així podrem anar provant la última versió beta, sino FALSE (!important)
 *
 * @type {boolean}
 */
var DEBUG = false;

/**
 * Informació justa i necessària de la aplicació: Nom paquet, versió MAJOR a demanar, ...
 *
 * @type {object}
 */
var APP = {
    PACKAGE: 'com.heartenergizer.app',
    VERSION: {
        MAJOR: '2'
    }
};

/**
 * Informació sobre el servidor on fer peticions
 *
 * @type {object}
 */
var SERVER = {};
SERVER.PROTOCOL = 'http';
SERVER.DOMAIN = 'heartenergizer.com';
SERVER.SUBDOMAIN = '';
SERVER.PATH = '/app';
SERVER.HOSTNAME = (SERVER.SUBDOMAIN ? SERVER.SUBDOMAIN + '.' : '') + SERVER.DOMAIN;
SERVER.HOST = SERVER.PROTOCOL + '://' + SERVER.HOSTNAME;
SERVER.BASE = SERVER.HOST + SERVER.PATH;
SERVER.WS = SERVER.BASE + '/ws';
SERVER.BOOTLOADER = SERVER.BASE + '/bootloader';


/***********************************************************************
 * RUNTIME
 ***********************************************************************/

/**
 * Comprovar i desar com a constant si estem dintre una App o no
 *
 * @type {boolean}
 */
IS_APP = window.cordova && (/(cdv)?file/i.test(window.location.protocol) || /^(cdv)?file:/i.test(window.location.href));

/**
 * Instància del bootloader
 * @type {BootLoader}
 */
var loader = null;



/***********************************************************************
 * INICIALITZACIÓ
 ***********************************************************************/

// If we are on a browser and current hostname/protocol does not match configured ones, redirect to right URL
if (!IS_APP && (window.location.hostname != SERVER.HOSTNAME || !(new RegExp(SERVER.PROTOCOL, 'i')).test(window.location.protocol))){
    window.location.replace(SERVER.BOOTLOADER);
}

/**
 * Event "document ready"
 */
function onBodyLoad()
{
    loader = new BootLoader(DEBUG);

    if (IS_APP)
    {
        document.addEventListener(
            'deviceready',
            function()
            {
                if(window.StatusBar){
                    // Treure StatusBar
                    // window.StatusBar.hide();
                }
                loader.initialize();
            },
            false
        );
    }
    else
    {
        loader.initialize();
    }
}



